from django.contrib import admin
from django.urls import include, path

admin.autodiscover()

urlpatterns = [
    path("admin/apps/tinymce/", include("tinymce.urls")),
    path("admin/apps/tags/", include("taggit_autosuggest.urls")),
    path("admin/", admin.site.urls),
    path("comments/", include("fluent_comments.urls")),
    # url(r'^forms/', include('form_designer.urls')),
    # Not including fluent_blogs.urls.
    # Instead, create a "blogpage" in the page tree.
    # all URLs will be displayed there.
    path("", include("fluent_pages.urls")),
]



# Generated by Django 1.11.9 on 2018-01-30 19:25

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("fluent_blogs", "0002_intro_allow_null"),
    ]

    operations = [
        migrations.AlterField(
            model_name="entry",
            name="author",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to=settings.AUTH_USER_MODEL,
                verbose_name="author",
            ),
        ),
    ]



from django.contrib import admin

from fluent_blogs.models import Entry, get_entry_model

from .abstractbase import (
    AbstractEntryBaseAdmin,
    AbstractTranslatableEntryBaseAdmin,
    SeoEntryAdminMixin,
)
from .entryadmin import EntryAdmin
from .forms import AbstractEntryBaseAdminForm, AbstractTranslatableEntryBaseAdminForm

__all__ = (
    "AbstractEntryBaseAdminForm",
    "AbstractTranslatableEntryBaseAdminForm",
    "AbstractEntryBaseAdmin",
    "AbstractTranslatableEntryBaseAdmin",
    "SeoEntryAdminMixin",
    "EntryAdmin",
)


# Ony register the admin when the entry model is not customized.
if get_entry_model() is Entry:
    admin.site.register(Entry, EntryAdmin)



from django.conf import settings
from django.core.exceptions import ImproperlyConfigured
from parler import appsettings as parler_appsettings
from parler.utils import is_supported_django_language, normalize_language_code

if "categories" in settings.INSTALLED_APPS:
    # old django-categories style. Keep first for backwards compatibility
    _default_category_model = "categories.Category"
elif "categories_i18n" in settings.INSTALLED_APPS:
    _default_category_model = "categories_i18n.Category"
else:
    # Default to new.
    _default_category_model = "categories_i18n.Category"


# Configurable permalink style, yeah!
FLUENT_BLOGS_ENTRY_LINK_STYLE = getattr(
    settings, "FLUENT_BLOGS_ENTRY_LINK_STYLE", "/{year}/{month}/{slug}/"
)

# Configurable admin fields
# By default, all optional mixin fields are detected.
FLUENT_BLOGS_EXTRA_ADMIN_FIELDS = getattr(settings, "FLUENT_BLOGS_EXTRA_ADMIN_FIELDS", ())
FLUENT_BLOGS_ADMIN_FIELDS = getattr(
    settings,
    "FLUENT_BLOGS_ADMIN_FIELDS",
    tuple(FLUENT_BLOGS_EXTRA_ADMIN_FIELDS)
    + ("excerpt_image", "excerpt_text", "contents", "categories", "tags", "enable_comments"),
)

# Advanced settings
FLUENT_BLOGS_FILTER_SITE_ID = getattr(settings, "FLUENT_BLOGS_FILTER_SITE_ID", True)
FLUENT_BLOGS_BASE_TEMPLATE = getattr(
    settings, "FLUENT_BLOGS_BASE_TEMPLATE", "fluent_blogs/base.html"
)
FLUENT_BLOGS_CATEGORY_MODEL = getattr(
    settings, "FLUENT_BLOGS_CATEGORY_MODEL", _default_category_model
)
FLUENT_BLOGS_ENTRY_MODEL = getattr(settings, "FLUENT_BLOGS_ENTRY_MODEL", "fluent_blogs.Entry")

# RSS feeds
FLUENT_BLOGS_FEED_PROTOCOL = getattr(settings, "FLUENT_BLOGS_FEED_PROTOCOL", "http")
FLUENT_BLOGS_MAX_FEED_ITEMS = getattr(settings, "FLUENT_BLOGS_MAX_FEED_ITEMS", 30)

# Comment settings
FLUENT_BLOGS_INCLUDE_STATIC_FILES = getattr(settings, "FLUENT_BLOGS_INCLUDE_STATIC_FILES", True)
FLUENT_BLOGS_PAGINATE_BY = getattr(settings, "FLUENT_BLOGS_PAGINATE_BY", 10)

# Performance settings
FLUENT_BLOGS_PREFETCH_TRANSLATIONS = getattr(settings, "FLUENT_BLOGS_PREFETCH_TRANSLATIONS", False)

# Note: the default language setting is used during the migrations
# Allow this module to have other settings, but default to the shared settings
FLUENT_DEFAULT_LANGUAGE_CODE = getattr(
    settings, "FLUENT_DEFAULT_LANGUAGE_CODE", parler_appsettings.PARLER_DEFAULT_LANGUAGE_CODE
)
FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE = getattr(
    settings, "FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE", FLUENT_DEFAULT_LANGUAGE_CODE
)
FLUENT_BLOGS_LANGUAGES = getattr(
    settings, "FLUENT_BLOGS_LANGUAGES", parler_appsettings.PARLER_LANGUAGES
)


# Clean settings
FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE = normalize_language_code(FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE)

if not is_supported_django_language(FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE):
    raise ImproperlyConfigured(
        f"FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE '{FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE}' does not exist in LANGUAGES"
    )

FLUENT_BLOGS_LANGUAGES = parler_appsettings.add_default_language_settings(
    FLUENT_BLOGS_LANGUAGES,
    "FLUENT_BLOGS_LANGUAGES",
    code=FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE,
    fallback=FLUENT_BLOGS_DEFAULT_LANGUAGE_CODE,
    hide_untranslated=False,
)


def get_language_settings(language_code, site_id=None):
    """
    Return the language settings for the current site
    """
    if site_id is None:
        site_id = getattr(settings, "SITE_ID", None)

    for lang_dict in FLUENT_BLOGS_LANGUAGES.get(site_id, ()):
        if lang_dict["code"] == language_code:
            return lang_dict

    return FLUENT_BLOGS_LANGUAGES["default"]



from django.conf import settings
from django.contrib.auth import get_user_model
from django.contrib.contenttypes.models import ContentType
from django.contrib.sitemaps import Sitemap
from parler.models import TranslatableModel

from fluent_blogs.models import get_category_model, get_entry_model
from fluent_blogs.urlresolvers import blog_reverse

User = get_user_model()
EntryModel = get_entry_model()
CategoryModel = get_category_model()


class EntrySitemap(Sitemap):
    """
    The sitemap definition for the pages created with django-fluent-blogs.
    """

    def items(self):
        qs = EntryModel.objects.published().order_by("-publication_date")

        if issubclass(EntryModel, TranslatableModel):
            # Note that .active_translations() can't be combined with other filters for translations__.. fields.
            qs = qs.active_translations()
            return qs.order_by("-publication_date", "translations__language_code")
        else:
            return qs.order_by("-publication_date")

    def lastmod(self, urlnode):
        """Return the last modification of the entry."""
        return urlnode.modification_date

    def location(self, urlnode):
        """Return url of an entry."""
        return urlnode.url


class CategoryArchiveSitemap(Sitemap):
    def items(self):
        only_ids = EntryModel.objects.published().values("categories").order_by().distinct()
        return CategoryModel.objects.filter(id__in=only_ids)

    def lastmod(self, category):
        """Return the last modification of the entry."""
        lastitems = (
            EntryModel.objects.published()
            .order_by("-modification_date")
            .filter(categories=category)
            .only("modification_date")
        )
        return lastitems[0].modification_date

    def location(self, category):
        """Return url of an entry."""
        return blog_reverse(
            "entry_archive_category", kwargs={"slug": category.slug}, ignore_multiple=True
        )


class AuthorArchiveSitemap(Sitemap):
    def items(self):
        only_ids = EntryModel.objects.published().values("author").order_by().distinct()
        return User.objects.filter(id__in=only_ids).order_by(User.USERNAME_FIELD)

    def lastmod(self, author):
        """Return the last modification of the entry."""
        lastitems = (
            EntryModel.objects.published()
            .order_by("-modification_date")
            .filter(author=author)
            .only("modification_date")
        )
        return lastitems[0].modification_date

    def location(self, author):
        """Return url of an entry."""
        return blog_reverse(
            "entry_archive_author", kwargs={"slug": author.get_username()}, ignore_multiple=True
        )


class TagArchiveSitemap(Sitemap):
    def items(self):
        # Tagging is optional. When it's not used, it's ignored.
        if "taggit" not in settings.INSTALLED_APPS:
            return []

        from taggit.models import Tag

        only_instances = EntryModel.objects.published().only("pk")

        # Use the same filters as TaggedItem.bulk_lookup_kwargs()
        return (
            Tag.objects.filter(
                taggit_taggeditem_items__object_id__in=only_instances,
                taggit_taggeditem_items__content_type=ContentType.objects.get_for_model(
                    EntryModel
                ),
            )
            .order_by("slug")
            .distinct()
        )

    def lastmod(self, tag):
        """Return the last modification of the entry."""
        lastitems = (
            EntryModel.objects.published()
            .order_by("-modification_date")
            .filter(tags=tag)
            .only("modification_date")
        )
        return lastitems[0].modification_date

    def location(self, tag):
        """Return url of an entry."""
        return blog_reverse("entry_archive_tag", kwargs={"slug": tag.slug}, ignore_multiple=True)



from django.contrib import admin
from django.urls import include, path

import fluent_blogs.urls

urlpatterns = [
    path("admin/", admin.site.urls),
    path("blog/", include(fluent_blogs.urls)),
]



from fluent_blogs.views.entries import (
    EntryArchiveIndex,
    EntryAuthorArchive,
    EntryCategoryArchive,
    EntryDayArchive,
    EntryDetail,
    EntryMonthArchive,
    EntryShortLink,
    EntryTagArchive,
    EntryYearArchive,
)

__all__ = (
    "EntryArchiveIndex",
    "EntryYearArchive",
    "EntryMonthArchive",
    "EntryDayArchive",
    "EntryDetail",
    "EntryShortLink",
    "EntryCategoryArchive",
    "EntryAuthorArchive",
    "EntryTagArchive",
)



from fluent_utils.softdeps.fluent_pages import mixed_reverse


def blog_reverse(viewname, args=None, kwargs=None, current_app="fluent_blogs", **page_kwargs):
    """
    Reverse a URL to the blog, taking various configuration options into account.

    This is a compatibility function to allow django-fluent-blogs to operate stand-alone.
    Either the app can be hooked in the URLconf directly, or it can be added as a pagetype of *django-fluent-pages*.
    """
    return mixed_reverse(
        viewname, args=args, kwargs=kwargs, current_app=current_app, **page_kwargs
    )


__all__ = ("blog_reverse",)



from ..base_models import AbstractEntry, AbstractTranslatableEntry, AbstractTranslatedFieldsEntry
from ..managers import EntryManager, TranslatableEntryManager  # noqa, old import paths
from .db import Entry, Entry_Translation, get_category_model, get_entry_model
from .query import get_category_for_slug

__all__ = (
    # Default translated models.
    "Entry",
    "Entry_Translation",
    # Default base models for classic and translated models.
    "AbstractEntry",
    "AbstractTranslatableEntry",
    "AbstractTranslatedFieldsEntry",
    # Utils for custom models.
    "get_entry_model",
    "get_category_model",
    "get_category_for_slug",
)
